==> haskell-digest-0.0.1.3-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-digest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 digest
version:              0.0.1.3
visibility:           public
id:                   digest-0.0.1.3-C6DBWiqAAOJ4bOuSrCgL0E
key:                  digest-0.0.1.3-C6DBWiqAAOJ4bOuSrCgL0E
license:              BSD-3-Clause
copyright:            (c) 2009 Eugene Kirpichov
maintainer:           Eugene Kirpichov <ekirpichov@gmail.com>
author:               Eugene Kirpichov <ekirpichov@gmail.com>
stability:            provisional
synopsis:
    Various cryptographic hashes for bytestrings; CRC32 and Adler32 for now.

description:
    This package provides efficient cryptographic hash implementations for
    strict and lazy bytestrings. For now, CRC32 and Adler32 are supported;
    they are implemented as FFI bindings to efficient code from zlib.

category:             Cryptography
abi:                  f61e59a61090767afe4379cd9ee25355
exposed:              True
exposed-modules:      Data.Digest.Adler32 Data.Digest.CRC32
import-dirs:          /usr/lib/ghc-9.0.1/site-local/digest-0.0.1.3
library-dirs:         /usr/lib/ghc-9.0.1/site-local/digest-0.0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/digest-0.0.1.3
hs-libraries:         HSdigest-0.0.1.3-C6DBWiqAAOJ4bOuSrCgL0E
extra-libraries:      z
includes:             zlib.h
depends:              base-4.15.0.0 bytestring-0.10.12.1
haddock-interfaces:   /usr/share/doc/haskell-digest/html/digest.haddock
haddock-html:         /usr/share/doc/haskell-digest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-digest-0.0.1.3-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-digest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 digest
version:              0.0.1.3
visibility:           public
id:                   digest-0.0.1.3-FvagnOoQhNmHZkKJfJWRNb
key:                  digest-0.0.1.3-FvagnOoQhNmHZkKJfJWRNb
license:              BSD-3-Clause
copyright:            (c) 2009 Eugene Kirpichov
maintainer:           Eugene Kirpichov <ekirpichov@gmail.com>
author:               Eugene Kirpichov <ekirpichov@gmail.com>
stability:            provisional
synopsis:
    Various cryptographic hashes for bytestrings; CRC32 and Adler32 for now.

description:
    This package provides efficient cryptographic hash implementations for
    strict and lazy bytestrings. For now, CRC32 and Adler32 are supported;
    they are implemented as FFI bindings to efficient code from zlib.

category:             Cryptography
abi:                  cd4a64c64463b2316bb5eb5ea8cb2832
exposed:              True
exposed-modules:      Data.Digest.Adler32 Data.Digest.CRC32
import-dirs:          /usr/lib/ghc-9.0.2/site-local/digest-0.0.1.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/digest-0.0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/digest-0.0.1.3
hs-libraries:         HSdigest-0.0.1.3-FvagnOoQhNmHZkKJfJWRNb
extra-libraries:      z
includes:             zlib.h
depends:              base-4.15.1.0 bytestring-0.10.12.1
haddock-interfaces:   /usr/share/doc/haskell-digest/html/digest.haddock
haddock-html:         /usr/share/doc/haskell-digest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
